==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/GatewayListFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface GatewayListFluent<A extends GatewayListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,Gateway item);
    public A setToItems(int index,Gateway item);
    public A addToItems(Gateway... items);
    public A addAllToItems(Collection<Gateway> items);
    public A removeFromItems(Gateway... items);
    public A removeAllFromItems(Collection<Gateway> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Gateway> getItems();
    public List<Gateway> buildItems();
    public Gateway buildItem(int index);
    public Gateway buildFirstItem();
    public Gateway buildLastItem();
    public Gateway buildMatchingItem(Predicate<GatewayBuilder> predicate);
    public A withItems(List<Gateway> items);
    public A withItems(Gateway... items);
    public Boolean hasItems();
    public GatewayListFluent.ItemsNested<A> addNewItem();
    public GatewayListFluent.ItemsNested<A> addNewItemLike(Gateway item);
    public GatewayListFluent.ItemsNested<A> setNewItemLike(int index,Gateway item);
    public GatewayListFluent.ItemsNested<A> editItem(int index);
    public GatewayListFluent.ItemsNested<A> editFirstItem();
    public GatewayListFluent.ItemsNested<A> editLastItem();
    public GatewayListFluent.ItemsNested<A> editMatchingItem(Predicate<GatewayBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,GatewayFluent<GatewayListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/GatewayListFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface GatewayListFluent<A extends GatewayListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Gateway item);
    public A setToItems(int index,Gateway item);
    public A addToItems(Gateway... items);
    public A addAllToItems(Collection<Gateway> items);
    public A removeFromItems(Gateway... items);
    public A removeAllFromItems(Collection<Gateway> items);
    public A removeMatchingFromItems(Predicate<GatewayBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Gateway> getItems();
    public List<Gateway> buildItems();
    public Gateway buildItem(int index);
    public Gateway buildFirstItem();
    public Gateway buildLastItem();
    public Gateway buildMatchingItem(Predicate<GatewayBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<GatewayBuilder> predicate);
    public A withItems(List<Gateway> items);
    public A withItems(Gateway... items);
    public Boolean hasItems();
    public GatewayListFluent.ItemsNested<A> addNewItem();
    public GatewayListFluent.ItemsNested<A> addNewItemLike(Gateway item);
    public GatewayListFluent.ItemsNested<A> setNewItemLike(int index,Gateway item);
    public GatewayListFluent.ItemsNested<A> editItem(int index);
    public GatewayListFluent.ItemsNested<A> editFirstItem();
    public GatewayListFluent.ItemsNested<A> editLastItem();
    public GatewayListFluent.ItemsNested<A> editMatchingItem(Predicate<GatewayBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,GatewayFluent<GatewayListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
